@@ -29,7 +29,7 @@ void iis_cur(float*x, float*y, char* ch) {
 
    /* Send read request */
 
-   hdr[TRANSFER_ID] = IREAD;
+   hdr[TRANSFER_ID] = PDL_IIS_IREAD;
    hdr[THING_COUNT] = 0;
    hdr[SUB_UNIT]   = IMCURSOR;
    hdr[CHECK_SUM]  = 0;
@@ -75,7 +75,7 @@ void iis_drawcirc(float xcen, float ycen, float radius, int colour, int frame) {
 
    /* Send WCS read request */
 
-   hdr[TRANSFER_ID] = -IREAD;
+   hdr[TRANSFER_ID] = -PDL_IIS_IREAD;
    hdr[THING_COUNT] = 0;
    hdr[SUB_UNIT]   = WCS;
    hdr[CHECK_SUM]  = 0;
@@ -132,7 +132,7 @@ void iis_drawcirc(float xcen, float ycen, float radius, int colour, int frame) {
 
       /* Read data */
 
-      hdr[TRANSFER_ID] = -IREAD | PACKED | BLOCKXFER;
+      hdr[TRANSFER_ID] = -PDL_IIS_IREAD | PACKED | BLOCKXFER;
       hdr[THING_COUNT] = -nlines*frameX;
       hdr[SUB_UNIT] = REFRESH;
       hdr[CHECK_SUM] = 0;
@@ -146,7 +146,7 @@ void iis_drawcirc(float xcen, float ycen, float radius, int colour, int frame) {
 
       /* Write data */
 
-      hdr[TRANSFER_ID] = IWRITE | PACKED | BLOCKXFER;
+      hdr[TRANSFER_ID] = PDL_IIS_IWRITE | PACKED | BLOCKXFER;
       hdr[THING_COUNT] = -nlines*frameX;
       hdr[SUB_UNIT] = REFRESH;
       hdr[CHECK_SUM] = 0;
@@ -236,10 +236,10 @@ void iis_open(char* inpipe, char* outpipe, int fb, int fbx, int fby) {
 
       /* Else look in standard places */
 
-      strncpy(iname,home,STRSIZE); strncat(iname,"/iraf/dev/imt1i",STRSIZE);
+      strncpy(iname,home,STRSIZE); strncat(iname,"/iraf/dev/imt1i",STRSIZE - strlen(iname) - 1);
       if (!access(iname,F_OK))
          goto gotin;
-      strncpy(iname,home,STRSIZE); strncat(iname,"/dev/imt1i",STRSIZE);
+      strncpy(iname,home,STRSIZE); strncat(iname,"/dev/imt1i",STRSIZE - strlen(iname) - 1);
       if (!access(iname,F_OK))
          goto gotin;
       strncpy(iname,"/dev/imt1i",STRSIZE);
@@ -266,10 +266,10 @@ void iis_open(char* inpipe, char* outpipe, int fb, int fbx, int fby) {
       }
       /* Else look in standard places */
 
-      strncpy(oname,home,STRSIZE); strncat(oname,"/iraf/dev/imt1o",STRSIZE);
+      strncpy(oname,home,STRSIZE); strncat(oname,"/iraf/dev/imt1o",STRSIZE - strlen(oname) - 1);
       if (!access(oname,F_OK))
          goto gotout;
-      strncpy(oname,home,STRSIZE); strncat(oname,"/dev/imt1o",STRSIZE);
+      strncpy(oname,home,STRSIZE); strncat(oname,"/dev/imt1o",STRSIZE - strlen(oname) - 1);
       if (!access(oname,F_OK))
          goto gotout;
       strncpy(oname,"/dev/imt1o",STRSIZE);
@@ -369,8 +369,10 @@ int iis_chan(int frame) {
    chan[1]=CHAN1; chan[2]=CHAN2; chan[3]=CHAN3; chan[4]=CHAN4;
    if (frame>0 && frame<5)
       return chan[frame];
-   else
+   else {
       iis_error("iis_display: invalid frame number, must be 1-4\n","");
+      return -1;
+   }
 }
 
 /* Round to nearest int symmetrically about zero */
